@@ -49,7 +49,7 @@ public:
         certificationsTV->setSelectionMode(QAbstractItemView::ExtendedSelection);
 
         auto vLay = new QVBoxLayout(q);
-        vLay->setMargin(0);
+        vLay->setContentsMargins(0, 0, 0, 0);
         vLay->addWidget(certificationsTV);
 
         connect(certificationsTV, &QAbstractItemView::doubleClicked,
@@ -92,11 +92,11 @@ public:
         /* Old style connect here again as QGPGME newstyle connects with
          * default arguments don't work on windows. */
 
-        connect(job, SIGNAL(result(GpgME::KeyListResult)),
-            q, SLOT(signatureListingDone(GpgME::KeyListResult)));
+        connect(job, &QGpgME::KeyListJob::result,
+            q, &WebOfTrustWidget::signatureListingDone);
 
-        connect(job, SIGNAL(nextKey(GpgME::Key)),
-            q, SLOT(signatureListingNextKey(GpgME::Key)));
+        connect(job, &QGpgME::KeyListJob::nextKey,
+            q, &WebOfTrustWidget::signatureListingNextKey);
 
         job->start(QStringList(QString::fromLatin1(key.primaryFingerprint())));
         keyListJob = job;
